@@ -15,5 +15,6 @@ Private interface
 """
 
 from .ep import EP
+from .ep_linear_kernel import EPLinearKernel
 
-__all__ = ['EP']
+__all__ = ['EP', 'EPLinearKernel']
