@@ -1,15 +1,16 @@
 from __future__ import division
 
 import pytest
+from numpy import arange, concatenate, inf, nan, newaxis, ones, sqrt, zeros
+from numpy.random import RandomState
+from numpy.testing import assert_allclose
+
 from glimix_core.cov import EyeCov, LinearCov, SumCov
 from glimix_core.lik import DeltaProdLik
 from glimix_core.lmm import LMM
 from glimix_core.lmm.core import LMMCore
 from glimix_core.mean import OffsetMean
 from glimix_core.random import GGPSampler
-from numpy import arange, concatenate, inf, nan, newaxis, ones, sqrt, zeros
-from numpy.random import RandomState
-from numpy.testing import assert_allclose
 from numpy_sugar.linalg import economic_qs_linear
 
 
@@ -113,9 +114,6 @@ def test_fastlmm_fast_scan_redundant():  # pylint: disable=R0914
         ],
         rtol=1e-5)
 
-    lmm.beta
-    pass
-
 
 def test_lmm_learn():
     random = RandomState(9458)
@@ -202,7 +200,7 @@ def test_fastlmm_learn_fix():
     assert_allclose(lmm.delta, 0.5)
     assert_allclose(lmm.genetic_variance, 0.5)
     assert_allclose(lmm.environmental_variance, 0.5)
-    assert_allclose(lmm.lml(), -681.381571238)
+    assert_allclose(lmm.lml(), -1162.109672730914)
 
     lmm.unfix('scale')
     lmm.learn(verbose=False)
