@@ -44,7 +44,7 @@ class GGPSampler(object):  # pylint: disable=R0903
         >>>
         >>> y = GGPSampler(lik, mean, cov).sample(random)
         >>> print(y[:5])
-        [ 1.67474605  1.24736152 -0.77509523  1.88952893  1.62847894]
+        [-1.93062099  0.99759953  1.14927833 -1.635114    0.77987918]
     """
 
     def __init__(self, lik, mean, cov):
